/************************************************************
 * Lara's House - Swimming Pool                             *
 * Re-modelled, based on TR3                                *
 *                                                          *
 * Chris Ware, 2008                                         *
 * Most textures by Anton Vuksanovic from Tomb Raider Xtra  *
 ************************************************************/

#include "column.inc"
#include "colors.inc"
#include "stones.inc"
#include "finish.inc"
#include "woods.inc"
#include "skies.inc"
#include "glass.inc"
#include "water.inc"
#include "firepillar.inc"
#include "switch.inc"

#default {finish{ambient 0.3}}

//Turn fires on or off - on slows rendering massively
#declare Fire_Enable = 1;

global_settings {
	ambient_light White
	photons {
	    spacing 0.005
	    load_file "photons.dat"
	}	
}

//Main Camera
camera {
	//location  <5,1,5>
	//look_at   <13,0.25,12> //Nice plants view
	//location <5,1,8>
	//look_at <5.6,1,0> //Fire pillar view
	//location <3,1,12>
	//look_at <9,0,4> //Full room from NW corner
	//location <9.3,0.6,12.8>
	//look_at <5.6,1,9> //Full room from behind plant
	location <4.5,0.1,9.5>
	look_at <9,0,0> //Pool reflections
}


sky_sphere {
	S_Cloud1
}
            
//Room
difference {
	//Room base
	box { <0,1.75,0>, <11,-4,14> }
	

	//Cutout main room
	box { <2,2.1,1>, <9,0,13.0000001> }  

	//Cutout alcoves
	box { <1,2.1,12>, <10,0.25,13> }
	box { <1,2.1,8>, <10,0.25,9> }
	box { <1,2.1,4>, <10,0.25,5> }
	
	//Cutout pool
	box { <3,0.1,6>, <8,-3,11> }

	//Cutout doorway
	box { <5,0.75,-0.1> <6,1.75,1.1> }
	
	texture{ pigment{White} }	
}


#declare GraniteArch = difference {
	cylinder {
		<5.5,-1.75,13>
		<5.5,-1.75,14>
		5		
	}
	box {
		<0,1.75,12.9>
		<14,-7,14.1>
	}
	texture{ T_Grnt15 finish {Shiny} }
}

//North top arch
object {
	GraniteArch
}

//South top arch
object {
	GraniteArch
	translate z*-13
}

#declare InnerRoofCylinder = cylinder {
		<5.5,-1.75,1>
		<5.5,-1.75,13>
		4.98		
	}

//Glass roof
#declare GlassRoof = difference {
	cylinder {
		<5.5,-1.75,1>
		<5.5,-1.75,13>
		5		
	}
    InnerRoofCylinder
	box {
		<0,1.75,0>
		<14,-7,14>
	}
	texture {T_Glass1}
}
//Sunlight "in" glass roof
light_source {
    <2, 5, 7.5>
    color White
    area_light <0, 0, 0>, <1, 1, 1>, 15, 15
    adaptive 1
    //jitter
    looks_like {GlassRoof}
    //media_interaction false
    
    //Photons for the water
    photons {
        reflection on
        refraction on
    }
}

//Roof window frames east-west
#declare EW_Roofframe = difference {
	cylinder {
		<5.5,-1.75,-0.05>
		<5.5,-1.75,0.05>
		5.001		
	}
	cylinder {
		<5.5,-1.75,-0.1>
		<5.5,-1.75,0.1>
		4.979		
	}
	box {
		<0,1.75,-1>
		<14,-7,1>
	}
	texture {pigment{White}}
}

#declare EW_RoofframePos=2;
#while (EW_RoofframePos <= 12)
	object {
		EW_Roofframe  
		translate <0,0,EW_RoofframePos>
	}
	#declare EW_RoofframePos=EW_RoofframePos+1;
#end

#declare NS_Roofframe = box {
	<-0.05,-0.05,1>
	<0.05,0.05,13>
	texture {pigment{White}}
} 

object {
	NS_Roofframe
	translate <3,2.58,0>
}
object {
	NS_Roofframe
	translate <4,3.02,0>
}
object {
	NS_Roofframe
	translate <5,3.22,0>
}
object {
	NS_Roofframe
	translate <6,3.22,0>
}
object {
	NS_Roofframe
	translate <7,3.02,0>
}
object {
	NS_Roofframe
	translate <8,2.58,0>
}

	

#declare GraniteRoof = box {
	<8,1.75,0>
	<11,2.25,14>
	texture{ T_Grnt15 finish {Shiny} }
}

//West Roof
object {
	GraniteRoof
}
object {
	GraniteRoof
	translate x*-8
}


//Steps in
box {
	<3,0,1>
	<8,0.25,3>
	texture{ pigment{White} }
}    
box {
	<4,0.25,1>
	<7,0.5,2>
	texture{ pigment{White} }
}

//Fire columns
object { 
	FirePillar(Fire_Enable, T_Stone17)
	translate <4.5,0,5.5>
}
object { 
	FirePillar(Fire_Enable, T_Stone17)
    rotate y*90
	translate <6.5,0,5.5>
}

//Pillars by fire - round off the tops to the roof
intersection {
    box {  
    	<4,0,4>
    	<5,3.25,5>
    	texture{ T_Grnt15 }
    }
    InnerRoofCylinder
}
intersection {
    box {  
    	<6,0,4>
    	<7,3.25,5>
    	texture{ T_Grnt15 }
    }
    InnerRoofCylinder
}

//Diving board steps
union {
	box {
		<5,0,11>
		<7,0.5,12>
	}     
	box {
		<7,0,11>
		<8,0.25,12>
	}           
	texture{pigment{White}}
}

//Diving board switch
object {
    Switch
    scale 0.6
    rotate y*180
    translate <5.5,0.2,12>
    finish {ambient 0.2}
}

//Diving board
box {
	<4.999,0.4,10>
	<6,0.51,12.001>
	texture{T_Wood3 finish {Glossy}}
}

//Water
difference {
    box {
    	<3,-0.25,6>
    	<8,-3,11>
    
    }
    
    //Bubbles    
    /*sphere {<6.9,-1.4,6.9> 0.07}
    sphere {<7,-1.3,6.95> 0.08}
    sphere {<7,-1.1,7> 0.06}
    sphere {<7.2,-1.5,6.9> 0.05}*/
    
    
   	material{Water}
	photons {
        target
        reflection on
        refraction on
    } 
}

#include "textiles.inc"
#include "tree1.inc"

object {
    tree1
    translate <9.5,0.25,12.5>
}
object {
    tree1
    rotate y*45
    translate <9.5,0.25,8.5>
}
object {
    tree1
    rotate y*90
    translate <9.5,0.25,4.5>
}
object {
    tree1
    rotate y*90
    translate <8.5,0,1.5>
}

object {
    tree1
    translate <1.5,0.25,12.5>
}
object {
    tree1
    rotate y*45
    translate <1.5,0.25,8.5>
}
object {
    tree1
    rotate y*90
    translate <1.5,0.25,4.5>
}
object {
    tree1
    rotate y*90
    translate <2.5,0,1.5>
}